.. image:: https://raw.githubusercontent.com/emsig/emg3d-logo/master/logo-emg3d-transp-web250px.png
   :target: https://emsig.xyz
   :alt: emg3d logo

|

.. image:: https://img.shields.io/pypi/v/emg3d.svg
   :target: https://pypi.python.org/pypi/emg3d/
   :alt: PyPI
.. image:: https://img.shields.io/conda/v/conda-forge/emg3d.svg
   :target: https://anaconda.org/conda-forge/emg3d/
   :alt: conda-forge
.. image:: https://img.shields.io/badge/python-3.7+-blue.svg
   :target: https://www.python.org/downloads/
   :alt: Supported Python Versions
.. image:: https://img.shields.io/badge/platform-linux,win,osx-blue.svg
   :target: https://anaconda.org/conda-forge/emg3d/
   :alt: Linux, Windows, OSX

|

A multigrid solver for 3D electromagnetic diffusion in Python.

- **Website:** https://emsig.xyz
- **Documentation:** https://emg3d.emsig.xyz
- **Source Code:** https://github.com/emsig/emg3d
- **Bug reports:** https://github.com/emsig/emg3d/issues
- **Contributing:** https://emg3d.emsig.xyz/en/latest/development
- **Contact:** http://slack.simpeg.xyz
- **Zenodo:** https://doi.org/10.5281/zenodo.3229006


Available through ``conda`` and ``pip``; consult the `documentation
<https://emg3d.emsig.xyz>`_ for detailed installation instructions.
